@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Inline;
 
-our $DATE = '2015-07-08'; # DATE
-our $VERSION = '0.15'; # VERSION
+our $DATE = '2015-07-30'; # DATE
+our $VERSION = '0.16'; # VERSION
 
 use 5.010001;
 use strict;
@@ -750,6 +750,14 @@ _
             "# DATE\n",
             "# VERSION\n",
             "# PODNAME: ", ($args{program_name} // ''), "\n",
+            do {
+                my $abstract = $args{summary} // $meta->{summary};
+                if ($abstract) {
+                    ("# ABSTRACT: ", $abstract, "\n");
+                } else {
+                    ();
+                }
+            },
             "\n",
 
             $dp_code1,
@@ -827,7 +835,7 @@ Perinci::CmdLine::Inline - Generate inline Perinci::CmdLine CLI script
 
 =head1 VERSION
 
-This document describes version 0.15 of Perinci::CmdLine::Inline (from Perl distribution Perinci-CmdLine-Inline), released on 2015-07-08.
+This document describes version 0.16 of Perinci::CmdLine::Inline (from Perl distribution Perinci-CmdLine-Inline), released on 2015-07-30.
 
 =head1 SYNOPSIS
 
@@ -853,31 +861,32 @@ B<EARLY DEVELOPMENT.>
 
 Sample startup overhead benchmark vs Perinci::CmdLine::Lite:
 
-                                   Rate  run 1 (lite) run --version (lite)   -c (lite) run 1 (inline) run --version (inline) -c (inline)   perl
- run 1 (lite)           13.515+-0.028/s            --               -61.5%      -82.3%         -89.2%                 -91.2%      -91.6% -97.4%
- run --version (lite)    35.07+-0.074/s 159.48+-0.77%                   --      -54.0%         -72.0%                 -77.1%      -78.1% -93.2%
- -c (lite)                76.23+-0.46/s     464+-3.6%          117.4+-1.4%          --         -39.2%                 -50.2%      -52.5% -85.3%
- run 1 (inline)          125.41+-0.29/s   827.9+-2.9%          257.6+-1.1%  64.5+-1.1%             --                 -18.1%      -21.8% -75.8%
- run --version (inline)  153.12+-0.98/s  1032.9+-7.6%          336.6+-2.9% 100.9+-1.8%    22.1+-0.83%                     --       -4.6% -70.5%
- -c (inline)               160.5+-2.9/s     1087+-22%          357.5+-8.4%   110.5+-4%       28+-2.3%                4.8+-2%          -- -69.1%
- perl                      519.1+-1.9/s     3741+-16%         1380.3+-6.2%   581+-4.8%      314+-1.8%              239+-2.5%   223.5+-6%     --
+                                   Rate run 1 (lite) run --version (lite)   -c (lite) run 1 (inline) run --version (inline) -c (inline)   perl
+ run 1 (lite)           12.905+-0.031/s           --               -61.7%      -82.4%         -88.7%                 -91.5%      -93.8% -97.5%
+ run --version (lite)   33.695+-0.078/s 161.1+-0.87%                   --      -53.9%         -70.6%                 -77.7%      -83.9% -93.6%
+ -c (lite)                73.15+-0.24/s  466.9+-2.3%        117.11+-0.88%          --         -36.1%                 -51.6%      -65.1% -86.0%
+ run 1 (inline)          114.53+-0.71/s  787.4+-5.9%          239.9+-2.2%  56.6+-1.1%             --                 -24.2%      -45.3% -78.2%
+ run --version (inline)      151+-1.1/s 1070.2+-9.1%          348.2+-3.5% 106.4+-1.7%     31.9+-1.3%                     --      -27.9% -71.2%
+ -c (inline)               209.3+-1.4/s    1522+-12%          521.3+-4.5% 186.1+-2.2%     82.8+-1.7%             38.6+-1.4%          -- -60.1%
+ perl                      524.4+-4.7/s    3964+-38%            1456+-14% 616.8+-6.9%      357.9+-5%              247.3+-4% 150.5+-2.8%     --
  
  Average times:
-   perl                  :     1.9264ms
-   -c (inline)           :     6.2305ms
-   run --version (inline):     6.5308ms
-   run 1 (inline)        :     7.9738ms
-   -c (lite)             :    13.1182ms
-   run --version (lite)  :    28.5144ms
-   run 1 (lite)          :    73.9919ms
+   perl                  :     1.9069ms
+   -c (inline)           :     4.7778ms
+   run --version (inline):     6.6225ms
+   run 1 (inline)        :     8.7313ms
+   -c (lite)             :    13.6705ms
+   run --version (lite)  :    29.6780ms
+   run 1 (lite)          :    77.4893ms
 
 =head1 FUNCTIONS
 
 
 =head2 gen_inline_pericmd_script(%args) -> [status, msg, result, meta]
 
-Generate inline Perinci::CmdLine CLI script.
+{en_US Generate inline Perinci::CmdLine CLI script}.
 
+{en_US 
 The goal of this module is to let you create a CLI script from a Riap
 function/metadata. This is like what C<Perinci::CmdLine::Lite> or
 C<Perinci::CmdLine::Classic> does, except that the generated CLI script will have
@@ -926,6 +935,7 @@ TODO:
 =item * Option to validate argument (using periswrap).
 
 =item * Support per_arg_json.
+}
 
 =back
 
@@ -935,7 +945,7 @@ Arguments ('*' denotes required arguments):
 
 =item * B<actions> => I<any>
 
-Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base.
+{en_US Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base}.
 
 =item * B<code_after_shebang> => I<str>
 
@@ -943,135 +953,137 @@ Currently does nothing, provided only for compatibility with Perinci::CmdLine::B
 
 =item * B<common_opts> => I<any>
 
-Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base.
+{en_US Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base}.
 
 =item * B<completion> => I<any>
 
-Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base.
+{en_US Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base}.
 
 =item * B<config_dirs> => I<any>
 
-Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base.
+{en_US Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base}.
 
 =item * B<config_filename> => I<any>
 
-Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base.
+{en_US Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base}.
 
 =item * B<default_subcommand> => I<any>
 
-Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base.
+{en_US Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base}.
 
 =item * B<description> => I<any>
 
-Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base.
+{en_US Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base}.
 
 =item * B<env_name> => I<any>
 
-Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base.
+{en_US Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base}.
 
 =item * B<exit> => I<any>
 
-Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base.
+{en_US Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base}.
 
 =item * B<extra_urls_for_version> => I<array[str]>
 
-More URLs to show version for --version.
+{en_US More URLs to show version for --version}.
 
+{en_US 
 Currently not implemented in Perinci::CmdLine::Inline.
+}
 
 =item * B<formats> => I<any>
 
-Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base.
+{en_US Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base}.
 
 =item * B<get_subcommand_from_arg> => I<any>
 
-Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base.
+{en_US Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base}.
 
 =item * B<include> => I<array[str]>
 
-Include extra modules.
+{en_US Include extra modules}.
 
 =item * B<log> => I<any>
 
-Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base.
+{en_US Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base}.
 
 =item * B<meta> => I<hash>
 
-An alternative to specifying `url`.
+{en_US An alternative to specifying `url`}.
 
 =item * B<meta_is_normalized> => I<bool>
 
 =item * B<output_file> => I<str>
 
-Set output file, defaults to stdout.
+{en_US Set output file, defaults to stdout}.
 
 =item * B<overwrite> => I<bool>
 
 =item * B<pass_cmdline_object> => I<bool> (default: 0)
 
-Whether to pass Perinci::CmdLine::Inline object.
+{en_US Whether to pass Perinci::CmdLine::Inline object}.
 
 =item * B<program_name> => I<str>
 
-Program name.
+{en_US Program name}.
 
 =item * B<program_version> => I<str>
 
-Program version (otherwise will use version from url metadata).
+{en_US Program version (otherwise will use version from url metadata)}.
 
 =item * B<read_config> => I<any>
 
-Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base.
+{en_US Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base}.
 
 =item * B<read_env> => I<any>
 
-Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base.
+{en_US Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base}.
 
 =item * B<riap_client> => I<any>
 
-Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base.
+{en_US Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base}.
 
 =item * B<riap_client_args> => I<any>
 
-Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base.
+{en_US Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base}.
 
 =item * B<riap_version> => I<any>
 
-Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base.
+{en_US Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base}.
 
 =item * B<shebang> => I<str>
 
-Set shebang line.
+{en_US Set shebang line}.
 
 =item * B<skip_format> => I<bool> (default: 0)
 
-Assume that function returns raw text that need no formatting, do not offer --format, --json, --naked-res.
+{en_US Assume that function returns raw text that need no formatting, do not offer --format, --json, --naked-res}.
 
 =item * B<sub_name> => I<str>
 
 =item * B<subcommands> => I<any>
 
-Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base.
+{en_US Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base}.
 
 =item * B<summary> => I<str>
 
-Program summary.
+{en_US Program summary}.
 
 =item * B<tags> => I<any>
 
-Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base.
+{en_US Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base}.
 
 =item * B<url> => I<str>
 
-Program URL.
+{en_US Program URL}.
 
 =item * B<validate_args> => I<bool> (default: 1)
 
-Whether to validate arguments using schemas.
+{en_US Whether to validate arguments using schemas}.
 
 =item * B<with_debug> => I<bool>
 
-Generate script with debugging outputs.
+{en_US Generate script with debugging outputs}.
 
 =back
 
